=========
ChangeLog
=========

.. contents:: Versions

0.9 - 2013.03.26
----------------

- Fixed #1: Travis for testing is available now.
- Fixed #2: Some routine files such as readme, license, etc.. .
- Fixed #3: Added more tests.
- Fixed #4: Added a tiny readme.
- Fixed #5: Wrote Docstring and Doctests for ``Base64Field`` class.
- Registered, Uploaded django-base64field for PyPi.
